﻿function New-SignedScript	{
<#
.SYNOPSIS
	Digitally signs a PowerShell script using a code signing certificate.

.DESCRIPTION
	Digitally signs a PowerShell script using a code signing certificate installed on the local machine.

.NOTES
  Version							: 1.1 - See changelog at http://www.ehloworld.com/2723
	Wish list						:
  Rights Required			: None
  Sched Task Required	: No
  Lync Server Version	: 2013 (tested through CU3)
  Author/Copyright		: © Pat Richard, Lync MVP - All Rights Reserved
  Email/Blog/Twitter	: pat@innervation.com 	http://www.ehloworld.com @patrichard
  Dedicated Post			: http://www.ehloworld.com/1496
  Disclaimer   				: You running this script means you won't blame me if this breaks your stuff. This script is
  											provided AS IS without warranty of any kind. I disclaim all implied warranties including,
  											without limitation, any implied warranties of merchantability or of fitness for a particular
  											purpose. The entire risk arising out of the use or performance of the sample scripts and
  											documentation remains with you. In no event shall I be liable for any damages whatsoever
  											(including, without limitation, damages for loss of business profits, business interruption,
  											loss of business information, or other pecuniary loss) arising out of the use of or inability
  											to use the script or documentation.
  Acknowledgements 		:
  Assumptions					: ExecutionPolicy of AllSigned (recommended), RemoteSigned or Unrestricted (not recommended)
  Limitations					:
  Known issues				: None yet, but I'm sure you'll find some!

.LINK
	http://www.ehloworld.com/1496

.EXAMPLE
	New-SignedScript .\MyScript.ps1

	Description
	-----------
	Runs script with default values.

.INPUTS
	None. You cannot pipe objects to this script.
#>
	#Requires -Version 2.0

	[CmdletBinding(SupportsShouldProcess = $True)]
	param (
		# Path (including file name) of script to sign
		[Parameter(ValueFromPipeline = $True, ValueFromPipelineByPropertyName = $True)]
	  [ValidateNotNullOrEmpty()]
		[string] $path
	)
	BEGIN	{
		$cert = @(Get-ChildItem cert:\currentuser\my -codesigning | Where-Object {$_.NotAfter -gt (Get-Date)} | Select-Object -First 1)
		if (! $cert){
			Write-Error "No valid codesigning certificate found"
			break
		}else{
			Write-Verbose "Valid certificate found: $cert"
		}
	}
	PROCESS	{
		if ((Get-AuthenticodeSignature $path).status -eq "NotSigned"){
			Write-Verbose "Signing $path with valid code signing certificate"
			# Set-AuthenticodeSignature $path $cert | Out-Null
			Set-AuthenticodeSignature $path $cert | Out-Null
			$valid = ((Get-AuthenticodeSignature $path).status -Match "Valid")
			if ($valid){
				Write-Verbose "Signing $path succeeded"
			}else{
				Write-Error "Signing $path failed"
			}
		}else{
			Write-Error "$path is already signed"
		}
	}
	END	{
		Remove-Variable Valid
		Remove-Variable Path
		Remove-Variable Cert
	}
}
# SIG # Begin signature block
# MIIQBQYJKoZIhvcNAQcCoIIP9jCCD/ICAQExCzAJBgUrDgMCGgUAMGkGCisGAQQB
# gjcCAQSgWzBZMDQGCisGAQQBgjcCAR4wJgIDAQAABBAfzDtgWUsITrck0sYpfvNR
# AgEAAgEAAgEAAgEAAgEAMCEwCQYFKw4DAhoFAAQUX6c41FPPUO3/qFIdiqMzn4ff
# f3eggg1KMIIGnzCCBYegAwIBAgIQCSu3nvOdPAJrDHL+XciEEzANBgkqhkiG9w0B
# AQUFADBvMQswCQYDVQQGEwJVUzEVMBMGA1UEChMMRGlnaUNlcnQgSW5jMRkwFwYD
# VQQLExB3d3cuZGlnaWNlcnQuY29tMS4wLAYDVQQDEyVEaWdpQ2VydCBBc3N1cmVk
# IElEIENvZGUgU2lnbmluZyBDQS0xMB4XDTEzMDgyODAwMDAwMFoXDTE0MDkwNDEy
# MDAwMFowazELMAkGA1UEBhMCVVMxCzAJBgNVBAgTAk1JMRkwFwYDVQQHExBTdGVy
# bGluZyBIZWlnaHRzMRkwFwYDVQQKExBJbm5lcnZhdGlvbiwgTExDMRkwFwYDVQQD
# ExBJbm5lcnZhdGlvbiwgTExDMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC
# AQEA8dXC+TSUZsMisaialKJLat7AnmOF0HE+U49duaBJp/N4IXhjUZM9sXRkR/X0
# KAbNauNpNrs3TLKNpO7/RUinzrzsg8IhtBVXSrK7c0HDqJ7vG181it2qQO1yB9uD
# UV8frjprnNcR1w0qW9wFqclKlkyOxgiCANVoT6qXO9IxPZT28h+tMfBCsU7sZALs
# 3kPRMCQ1ZywngVSqEQ9rBYV3jW4EgvPEOmuhtnwgVB1Alr2V1dVAtbNxw1A7fQ8w
# J6EQSNAPVJQq7304QKKgGaTXtA2TwAjO5+m9ZltD/s0wXWYs0V1r8pOJOo1r17l4
# z91OWLPP+yfxvlnm5F1IXZxCbQIDAQABo4IDOTCCAzUwHwYDVR0jBBgwFoAUe2jO
# KarAF75JeuHlP9an90WPNTIwHQYDVR0OBBYEFB9N9j4QNDPcSscWMAVDKCOcXS/G
# MA4GA1UdDwEB/wQEAwIHgDATBgNVHSUEDDAKBggrBgEFBQcDAzBzBgNVHR8EbDBq
# MDOgMaAvhi1odHRwOi8vY3JsMy5kaWdpY2VydC5jb20vYXNzdXJlZC1jcy0yMDEx
# YS5jcmwwM6AxoC+GLWh0dHA6Ly9jcmw0LmRpZ2ljZXJ0LmNvbS9hc3N1cmVkLWNz
# LTIwMTFhLmNybDCCAcQGA1UdIASCAbswggG3MIIBswYJYIZIAYb9bAMBMIIBpDA6
# BggrBgEFBQcCARYuaHR0cDovL3d3dy5kaWdpY2VydC5jb20vc3NsLWNwcy1yZXBv
# c2l0b3J5Lmh0bTCCAWQGCCsGAQUFBwICMIIBVh6CAVIAQQBuAHkAIAB1AHMAZQAg
# AG8AZgAgAHQAaABpAHMAIABDAGUAcgB0AGkAZgBpAGMAYQB0AGUAIABjAG8AbgBz
# AHQAaQB0AHUAdABlAHMAIABhAGMAYwBlAHAAdABhAG4AYwBlACAAbwBmACAAdABo
# AGUAIABEAGkAZwBpAEMAZQByAHQAIABDAFAALwBDAFAAUwAgAGEAbgBkACAAdABo
# AGUAIABSAGUAbAB5AGkAbgBnACAAUABhAHIAdAB5ACAAQQBnAHIAZQBlAG0AZQBu
# AHQAIAB3AGgAaQBjAGgAIABsAGkAbQBpAHQAIABsAGkAYQBiAGkAbABpAHQAeQAg
# AGEAbgBkACAAYQByAGUAIABpAG4AYwBvAHIAcABvAHIAYQB0AGUAZAAgAGgAZQBy
# AGUAaQBuACAAYgB5ACAAcgBlAGYAZQByAGUAbgBjAGUALjCBggYIKwYBBQUHAQEE
# djB0MCQGCCsGAQUFBzABhhhodHRwOi8vb2NzcC5kaWdpY2VydC5jb20wTAYIKwYB
# BQUHMAKGQGh0dHA6Ly9jYWNlcnRzLmRpZ2ljZXJ0LmNvbS9EaWdpQ2VydEFzc3Vy
# ZWRJRENvZGVTaWduaW5nQ0EtMS5jcnQwDAYDVR0TAQH/BAIwADANBgkqhkiG9w0B
# AQUFAAOCAQEABTcbxhPxSJP7AKrF23wXbgelEGzjpewmm0BnHO9/V+9K4UE/3i5Z
# e3bX7OvUb/55zCHT4pvZl8/i8tuvFnrWZZcjGljT3W9SIVOuKNdlItXC8dvP67Hz
# OMZvSbdI5MU6sjd3vyYKznTMHG1Mz/x+BMh6rEnGsIaY4r8r4fkNfJTyTkww8AWh
# I16Pno3dWgKhfploPODtMxczJKA15VDFhQqM3oHHMojasXo5uGb5jlGiDFkZ3mDa
# /+gLUsJUjAzF27ZIy/jRgp0eMkqlgdxGa+gZUK73Ue6aTP2LW9SL/1fLYl8QkwRs
# MWG1faGdureT3Oh0EHH6UhREB/SxLJ+xLTCCBqMwggWLoAMCAQICEA+oSQYV1wCg
# viF2/cXsbb0wDQYJKoZIhvcNAQEFBQAwZTELMAkGA1UEBhMCVVMxFTATBgNVBAoT
# DERpZ2lDZXJ0IEluYzEZMBcGA1UECxMQd3d3LmRpZ2ljZXJ0LmNvbTEkMCIGA1UE
# AxMbRGlnaUNlcnQgQXNzdXJlZCBJRCBSb290IENBMB4XDTExMDIxMTEyMDAwMFoX
# DTI2MDIxMDEyMDAwMFowbzELMAkGA1UEBhMCVVMxFTATBgNVBAoTDERpZ2lDZXJ0
# IEluYzEZMBcGA1UECxMQd3d3LmRpZ2ljZXJ0LmNvbTEuMCwGA1UEAxMlRGlnaUNl
# cnQgQXNzdXJlZCBJRCBDb2RlIFNpZ25pbmcgQ0EtMTCCASIwDQYJKoZIhvcNAQEB
# BQADggEPADCCAQoCggEBAJx8+aCPCsqJS1OaPOwZIn8My/dIRNA/Im6aT/rO38bT
# JJH/qFKT53L48UaGlMWrF/R4f8t6vpAmHHxTL+WD57tqBSjMoBcRSxgg87e98tzL
# uIZARR9P+TmY0zvrb2mkXAEusWbpprjcBt6ujWL+RCeCqQPD/uYmC5NJceU4bU7+
# gFxnd7XVb2ZklGu7iElo2NH0fiHB5sUeyeCWuAmV+UuerswxvWpaQqfEBUd9YCvZ
# oV29+1aT7xv8cvnfPjL93SosMkbaXmO80LjLTBA1/FBfrENEfP6ERFC0jCo9dAz0
# eotyS+BWtRO2Y+k/Tkkj5wYW8CWrAfgoQebH1GQ7XasCAwEAAaOCA0MwggM/MA4G
# A1UdDwEB/wQEAwIBhjATBgNVHSUEDDAKBggrBgEFBQcDAzCCAcMGA1UdIASCAbow
# ggG2MIIBsgYIYIZIAYb9bAMwggGkMDoGCCsGAQUFBwIBFi5odHRwOi8vd3d3LmRp
# Z2ljZXJ0LmNvbS9zc2wtY3BzLXJlcG9zaXRvcnkuaHRtMIIBZAYIKwYBBQUHAgIw
# ggFWHoIBUgBBAG4AeQAgAHUAcwBlACAAbwBmACAAdABoAGkAcwAgAEMAZQByAHQA
# aQBmAGkAYwBhAHQAZQAgAGMAbwBuAHMAdABpAHQAdQB0AGUAcwAgAGEAYwBjAGUA
# cAB0AGEAbgBjAGUAIABvAGYAIAB0AGgAZQAgAEQAaQBnAGkAQwBlAHIAdAAgAEMA
# UAAvAEMAUABTACAAYQBuAGQAIAB0AGgAZQAgAFIAZQBsAHkAaQBuAGcAIABQAGEA
# cgB0AHkAIABBAGcAcgBlAGUAbQBlAG4AdAAgAHcAaABpAGMAaAAgAGwAaQBtAGkA
# dAAgAGwAaQBhAGIAaQBsAGkAdAB5ACAAYQBuAGQAIABhAHIAZQAgAGkAbgBjAG8A
# cgBwAG8AcgBhAHQAZQBkACAAaABlAHIAZQBpAG4AIABiAHkAIAByAGUAZgBlAHIA
# ZQBuAGMAZQAuMBIGA1UdEwEB/wQIMAYBAf8CAQAweQYIKwYBBQUHAQEEbTBrMCQG
# CCsGAQUFBzABhhhodHRwOi8vb2NzcC5kaWdpY2VydC5jb20wQwYIKwYBBQUHMAKG
# N2h0dHA6Ly9jYWNlcnRzLmRpZ2ljZXJ0LmNvbS9EaWdpQ2VydEFzc3VyZWRJRFJv
# b3RDQS5jcnQwgYEGA1UdHwR6MHgwOqA4oDaGNGh0dHA6Ly9jcmwzLmRpZ2ljZXJ0
# LmNvbS9EaWdpQ2VydEFzc3VyZWRJRFJvb3RDQS5jcmwwOqA4oDaGNGh0dHA6Ly9j
# cmw0LmRpZ2ljZXJ0LmNvbS9EaWdpQ2VydEFzc3VyZWRJRFJvb3RDQS5jcmwwHQYD
# VR0OBBYEFHtozimqwBe+SXrh5T/Wp/dFjzUyMB8GA1UdIwQYMBaAFEXroq/0ksuC
# MS1Ri6enIZ3zbcgPMA0GCSqGSIb3DQEBBQUAA4IBAQB7ch1k/4jIOsG36eepxIe7
# 25SS15BZM/orh96oW4AlPxOPm4MbfEPE5ozfOT7DFeyw2jshJXskwXJduEeRgRNG
# +pw/alE43rQly/Cr38UoAVR5EEYk0TgPJqFhkE26vSjmP/HEqpv22jVTT8nyPdNs
# 3CPtqqBNZwnzOoA9PPs2TJDndqTd8jq/VjUvokxl6ODU2tHHyJFqLSNPNzsZlBjU
# 1ZwQPNWxHBn/j8hrm574rpyZlnjRzZxRFVtCJnJajQpKI5JA6IbeIsKTOtSbaKbf
# KX8GuTwOvZ/EhpyCR0JxMoYJmXIJeUudcWn1Qf9/OXdk8YSNvosesn1oo6WQsQz/
# MYICJTCCAiECAQEwgYMwbzELMAkGA1UEBhMCVVMxFTATBgNVBAoTDERpZ2lDZXJ0
# IEluYzEZMBcGA1UECxMQd3d3LmRpZ2ljZXJ0LmNvbTEuMCwGA1UEAxMlRGlnaUNl
# cnQgQXNzdXJlZCBJRCBDb2RlIFNpZ25pbmcgQ0EtMQIQCSu3nvOdPAJrDHL+XciE
# EzAJBgUrDgMCGgUAoHgwGAYKKwYBBAGCNwIBDDEKMAigAoAAoQKAADAZBgkqhkiG
# 9w0BCQMxDAYKKwYBBAGCNwIBBDAcBgorBgEEAYI3AgELMQ4wDAYKKwYBBAGCNwIB
# FTAjBgkqhkiG9w0BCQQxFgQUWEiv5P6FvYcMGCrKBCFRpbLKTzUwDQYJKoZIhvcN
# AQEBBQAEggEAO/IpfF0XJAMnf0/BUHyPXHfB/U1XyRiWI+ROdSbOte+wLLsO3U1C
# YFcYNJFuuFv/vWuDrCs22XN4n75okFWNd4y21oTYF5GvxwH5uTbpxeQx6jZCtcXc
# CAOvBYcvoNp/DZAt+GzaeNh7CdbYA64YalYs49jKkIhdFNJFH71o3J7So+ayBMFY
# W/+iGVa/UB6Ktumn11zT+ozMTmdF8frElu/yS8gBpMQlvTz5IxK5GiW2olWK6QI7
# 5t9IZ5iPu4iqeBUy77ed4jvz3ne6/wWQr3Npm2ZlhnquD4nL9OrcG2iMeF9k6Pya
# pSu+85nyXadpwjb8F18JdXcYgvruzJj09w==
# SIG # End signature block
